@@ -174,7 +174,7 @@ class BigQueryClient(object):
 
         return True
 
-    def make_dataset(self, dataset, raise_if_exists=False, body={}):
+    def make_dataset(self, dataset, raise_if_exists=False, body=None):
         """Creates a new dataset with the default permissions.
 
            :param dataset:
@@ -183,6 +183,9 @@ class BigQueryClient(object):
            :raises luigi.target.FileAlreadyExists: if raise_if_exists=True and the dataset exists
         """
 
+        if body is None:
+            body = {}
+
         try:
             body['id'] = '{}:{}'.format(dataset.project_id, dataset.dataset_id)
             if dataset.location is not None:
@@ -424,7 +427,7 @@ class MixinBigQueryBulkComplete(object):
         tasks_with_params = [(cls(p), p) for p in parameter_tuples]
 
         # Grab the set of BigQuery datasets we are interested in
-        datasets = set([t.output().table.dataset for t, p in tasks_with_params])
+        datasets = {t.output().table.dataset for t, p in tasks_with_params}
         logger.info('Checking datasets %s for available tables', datasets)
 
         # Query the available tables for all datasets
