@@ -23,6 +23,8 @@ from __future__ import print_function
 
 import hashlib
 import os
+import sys
+from subprocess import Popen, PIPE
 
 from luigi import six
 
@@ -41,6 +43,20 @@ def getpcmd(pid):
             if lines:
                 _, val = lines
                 return val
+    elif sys.platform == "darwin":
+        # Use pgrep instead of /proc on macOS.
+        pidfile = ".%d.pid" % (pid, )
+        with open(pidfile, 'w') as f:
+            f.write(str(pid))
+        try:
+            p = Popen(['pgrep', '-lf', '-F', pidfile], stdout=PIPE)
+            stdout, _ = p.communicate()
+            line = stdout.decode('utf8').strip()
+            if line:
+                _, scmd = line.split(' ', 1)
+                return scmd
+        finally:
+            os.unlink(pidfile)
     else:
         # Use the /proc filesystem
         # At least on android there have been some issues with not all
@@ -49,7 +65,10 @@ def getpcmd(pid):
         # https://github.com/spotify/luigi/pull/1876
         try:
             with open('/proc/{0}/cmdline'.format(pid), 'r') as fh:
-                return fh.read().replace('\0', ' ').rstrip()
+                if six.PY3:
+                    return fh.read().replace('\0', ' ').rstrip()
+                else:
+                    return fh.read().replace('\0', ' ').decode('utf8').rstrip()
         except IOError:
             # the system may not allow reading the command line
             # of a process owned by another user
@@ -65,12 +84,7 @@ def get_info(pid_dir, my_pid=None):
         my_pid = os.getpid()
 
     my_cmd = getpcmd(my_pid)
-
-    if six.PY3:
-        cmd_hash = my_cmd.encode('utf8')
-    else:
-        cmd_hash = my_cmd
-
+    cmd_hash = my_cmd.encode('utf8')
     pid_file = os.path.join(pid_dir, hashlib.md5(cmd_hash).hexdigest()) + '.pid'
 
     return my_pid, my_cmd, pid_file
