@@ -301,20 +301,20 @@ function visualiserApp(luigi) {
         $("#statusMessageModal").modal({});
         var refreshInterval = setInterval(function() {
                 if ($("#statusMessageModal").is(":hidden"))
-                    clearInterval(refreshInterval)
+                    clearInterval(refreshInterval);
                 else {
                     luigi.getTaskStatusMessage(data.taskId, function(data) {
                         if (data.statusMessage === null)
-                            $("#statusMessageModal pre").hide()
+                            $("#statusMessageModal pre").hide();
                         else {
                             $("#statusMessageModal pre").html(data.statusMessage).show();
                         }
                     });
                     luigi.getTaskProgressPercentage(data.taskId, function(data) {
                         if (data.progressPercentage === null)
-                            $("#statusMessageModal .progress").hide()
+                            $("#statusMessageModal .progress").hide();
                         else {
-                            $("#statusMessageModal .progress").show()
+                            $("#statusMessageModal .progress").show();
                             $("#statusMessageModal .progress-bar")
                                 .attr('aria-valuenow', data.progressPercentage)
                                 .text(data.progressPercentage + '%')
@@ -462,7 +462,7 @@ function visualiserApp(luigi) {
 
             // Populate fields with values from hash.
             if (fragmentQuery.length) {
-                $('select[name=taskTable_length').val(fragmentQuery.length);
+                $('select[name=taskTable_length]').val(fragmentQuery.length);
             }
             $("#serverSideCheckbox").prop('checked', fragmentQuery.filterOnServer === '1' ? true : false);
             dt.search(fragmentQuery.search__search);
@@ -516,7 +516,7 @@ function visualiserApp(luigi) {
             $(".graph-node-a").click(function(event) {
                 var taskId = $(this).attr("data-task-id");
                 var status = $(this).attr("data-task-status");
-                if (status=="FAILED") {
+                if (status == "FAILED") {
                     event.preventDefault();
                     luigi.getErrorTrace(taskId, function(error) {
                        showErrorTrace(error);
@@ -581,7 +581,7 @@ function visualiserApp(luigi) {
         var times = {};
         for (var i = 0; i < listId.length; i++) {
             for (var j = 0; j < tasks.length; j++) {
-                if (listId[i]===tasks[j].taskId) {
+                if (listId[i] === tasks[j].taskId) {
                     var finishTime = new Date(tasks[j].time_running*1000);
                     var startTime = new Date(tasks[j].start_time*1000);
                     var durationTime = new Date((finishTime - startTime)*1000).getSeconds();
@@ -743,7 +743,7 @@ function visualiserApp(luigi) {
         var taskCount;
         /* Check for integers in tasks.  This indicates max-shown-tasks was exceeded */
         if (tasks.length === 1 && typeof(tasks[0]) === 'number') {
-            taskCount = tasks[0];
+            taskCount = tasks[0] === -1 ? 'unknown' : tasks[0];
             missingCategories[category] = {name: category, count: taskCount};
         }
         else {
@@ -1182,6 +1182,7 @@ function visualiserApp(luigi) {
             }
         });
 
+        processHashChange();
         updateTasks();
         bindListEvents();
 
@@ -1195,20 +1196,29 @@ function visualiserApp(luigi) {
         } );
 
         $('#taskTable tbody').on('click', 'td.details-control .forgiveFailures', function (ev) {
-            var tr = $(this).closest('tr');
+            var that = $(this);
+            var tr = that.closest('tr');
             var row = dt.row( tr );
             var data = row.data();
             luigi.forgiveFailures(data.taskId, function(data) {
-                if (ev.altKey){
+                if (ev.altKey) {
                     updateTasks(); // update may not be cheap
+                } else {
+                    that.tooltip('hide');
+                    that.remove();
                 }
             });
         } );
 
-        $('#taskTable tbody').on('click', 'td.details-control .re-enable-button', function () {
+        $('#taskTable tbody').on('click', 'td.details-control .re-enable-button', function (ev) {
             var that = $(this);
-            luigi.reEnable($(this).attr("data-task-id"), function(data) {
-                updateTasks();
+            luigi.reEnable(that.attr("data-task-id"), function(data) {
+                if (ev.altKey) {
+                    updateTasks(); // update may not be cheap
+                } else {
+                    that.tooltip('hide');
+                    that.remove();
+                }
             });
         });
 
