@@ -428,8 +428,7 @@ class Task(object):
         for key, value in param_values:
             setattr(self, key, value)
 
-        # Register args and kwargs as an attribute on the class. Might be useful
-        self.param_args = tuple(value for key, value in param_values)
+        # Register kwargs as an attribute on the class. Might be useful
         self.param_kwargs = dict(param_values)
 
         self._warn_on_wrong_param_types()
@@ -440,6 +439,11 @@ class Task(object):
         self.set_status_message = None
         self.set_progress_percentage = None
 
+    @property
+    def param_args(self):
+        warnings.warn("Use of param_args has been deprecated.", DeprecationWarning)
+        return tuple(self.param_kwargs[k] for k, v in self.get_params())
+
     def initialized(self):
         """
         Returns ``True`` if the Task is initialized and ``False`` otherwise.
@@ -528,7 +532,7 @@ class Task(object):
         return task_str
 
     def __eq__(self, other):
-        return self.__class__ == other.__class__ and self.param_args == other.param_args
+        return self.__class__ == other.__class__ and self.param_kwargs == other.param_kwargs
 
     def complete(self):
         """
